Coverage for src/django_resume/apps.py: 100%

1 from django.apps import AppConfig

2

3

4 class ResumeConfig(AppConfig):

5 default_auto_field = "django.db.models.BigAutoField"

6 name = "django_resume"

7

8 @staticmethod

9 def register_plugins():

10 from .plugins import (

11 FreelanceTimelinePlugin,

12 EmployedTimelinePlugin,

13 TokenPlugin,

14 ProjectsPlugin,

15 EducationPlugin,

16 AboutPlugin,

17 SkillsPlugin,

18 IdentityPlugin,

19 plugin_registry,

20 )

21

22 plugin_registry.register(FreelanceTimelinePlugin)

23 plugin_registry.register(EmployedTimelinePlugin)

24 plugin_registry.register(EducationPlugin)

25 plugin_registry.register(ProjectsPlugin)

26 plugin_registry.register(AboutPlugin)

27 plugin_registry.register(SkillsPlugin)

28 plugin_registry.register(TokenPlugin)

29 plugin_registry.register(IdentityPlugin)

30

31 def ready(self):

32 self.register_plugins()